@@ -18,8 +18,9 @@ class Backend(BaseBackend):
 
         try:
             for payload in check.generate():
-                datawatch.get_backend().run(
-                    check.slug, check.get_identifier(payload))
+                if payload is None:
+                    continue
+                datawatch.get_backend().run(check.slug, check.get_identifier(payload))
         except NotImplementedError as e:
             logger.error(e)
 
